{{/*
Common labels
*/}}
{{- define "elasticsearch.labels" -}}
{{ include "elasticsearch-utils.labels" . }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "elasticsearch.selectorLabels" -}}
{{ include "elasticsearch-utils.selectorLabels" . }}
{{- end -}}

{{/*
    Region is not required as elasticsearch clusters are scoped within a region/account.
    This is shortened from typical naming because ES domains have a 28 character limit.
    Steering away from the normal pattern because of strict requirements the ElasticSearch
    service imposes on us.
*/}}
{{- define "elasticsearch._clusterDomainName" -}}
{{- .Values.global.env -}}-
{{- required ".Values.clusterDomainName is a required value" .Values.clusterDomainName -}}
{{- end -}}

{{/*
  Es domain name
*/}}
{{- define "elasticsearch.clusterDomainName" -}}
{{- if include "elasticsearch._clusterDomainName" . | replace "_" "-" | trimSuffix "-" | len | int64 | ge 28 -}}
{{- include "elasticsearch._clusterDomainName" . | replace "_" "-" | trimSuffix "-" -}}
{{- else -}}
{{- include "elasticsearch._clusterDomainName" . | replace "_" "-" | trimSuffix "-" | print "\nError: The generated external name is longer than 28 chars. \nPlease provide a shorter .Values.clusterDomainName \nGenerated clusterDomainName: " | fail -}}
{{- end -}}
{{- end -}}

{{/*
  The kubernetes service name for the db endpoint
*/}}
{{- define "elasticsearch.clusterEndpoint" -}}
  {{ include "elasticsearch-utils.namingPrefix" . }}-endpoint.{{ include "elasticsearch-utils.appsNamespace" . }}.svc.cluster.local
{{- end -}}

{{/*
  The kubernetes sort service name for the db endpoint
*/}}
{{- define "elasticsearch.clusterEndpointShortName" -}}
  {{ include "elasticsearch-utils.namingPrefix" . }}-endpoint
{{- end -}}

{{/*
  Check versions for compatible list
*/}}
{{- define "elasticsearch.getVersion" -}}
{{- if has .Values.esVersion .Values.compatibleVersions -}}
{{- if and (hasPrefix "2" .Values.esVersion) (.Values.global.awsDeployment) -}}
{{- fail "esVersion 2 is not supported in AWS Deployments" -}}
{{- else -}}
{{- .Values.esVersion -}}
{{- end -}}
{{- else -}}
{{- fail "The esVersion passed in is not supported in AWS deployments" -}}
{{- end -}}
{{- end -}}

{{- /*
  Return image name for local deployments
*/ -}}
{{- define "elasticsearch.getLocalImage" -}}
{{- $image := "library/elasticsearch" -}}
{{- if (default nil .Values.localDeployment.image) -}}
{{- .Values.localDeployment.image -}}
{{- else if has .Values.esVersion .Values.compatibleVersions -}}
  {{- if semverCompare "~2" .Values.esVersion -}}
{{- printf "%s:%s" $image "2.4.3" -}}
  {{- else if semverCompare "~5" .Values.esVersion -}}
{{- printf "%s:%s" $image "5" -}}
  {{- else if semverCompare "~6" .Values.esVersion -}}
{{- printf "%s:%s" $image "6.8.13" -}}
  {{- else if semverCompare "~7" .Values.esVersion -}}
{{- printf "%s:%s" $image "7.10.1" -}}
  {{- else -}}
fail "The esVersion passed in is not supported in local deployments"
  {{- end -}}
{{- end -}}
{{- end -}}

{{/*
  The user password secret name
*/}}
{{- define "elasticsearch.dbUserPassCredentialsSecretName" -}}
  {{ include "elasticsearch-utils.namingPrefix" . }}-es-pass
{{- end -}}

{{- /*
  Generate a Username to use as the master user
  Moving this here out of gen-primary-secret.sh so that it can be unit tested.

  Starts with the namingPrefix and tries to crop it down to 16 chars or less.
*/ -}}
{{- define "elasticsearch.username" -}}
  {{- $maxLength := 16 -}}
  {{- if .Values.esClusterMasterUserName }}
    {{- printf .Values.esClusterMasterUserName | trunc $maxLength }}
  {{- else }}
    {{- splitList "-" (include "elasticsearch-utils.namingPrefix" .) | last | trunc $maxLength -}}
  {{- end }}
{{- end -}}

{{/*
  The user username secret name
*/}}
{{- define "elasticsearch.dbUserUsernameCredentialsSecretName" -}}
  {{ include "elasticsearch-utils.namingPrefix" . }}-es-user
{{- end -}}

{{/*
  Local Deployment Resource Settings
*/}}
{{- define "elasticsearch.localDeploymentResourceValues" -}}
requests:
  cpu: {{ .Values.localDeployment.resources.requests.cpu }}
  memory: {{ .Values.localDeployment.resources.requests.memory }}
limits:
  memory: {{ .Values.localDeployment.resources.limits.memory }}
{{- end -}}

{{/*
  Defines the ouput params for -outputs config map
*/}}
{{- define "elasticsearch.outputCMParams" -}}
arnConfigMap: "{{ include "elasticsearch-utils.namingPrefix" . }}-arn"
{{- if .Values.existingInfraOverrides.enable }}
clusterDomainName: {{ required "You must specify the value for existing Elasticsearch cluster domainName '.Values.existingInfraOverrides.clusterDomainName' to be created."  .Values.existingInfraOverrides.clusterDomainName }}
{{ else }}
clusterDomainName: {{ include "elasticsearch.clusterDomainName" . }}
{{ end }}
dbServiceClusterEndpointShortName: {{ include "elasticsearch.clusterEndpointShortName" . }}
dbServiceClusterEndpoint: {{ include "elasticsearch.clusterEndpoint" . }}
{{- end }}

{{/*
  Defines the output params for -arn config map
*/}}
{{- define "elasticsearch.arnCMParams" -}}
{{- if not ( and .Values.existingInfraOverrides.clusterDomainName .Values.existingInfraOverrides.arn .Values.existingInfraOverrides.clusterEndpoint ) }}
{{ printf ("\n\nIf you have set \".Values.existingInfraOverrides.enable\" as true then please provide a value for the existing Elasticsearch domainName, arn, clusterEndpoint: \".Values.existingInfraOverrides.clusterDomainName\" and \".Values.existingInfraOverrides.arn\" and \".Values.existingInfraOverrides.clusterEndpoint\"") | fail }}
{{- end }}
ARN: {{ .Values.existingInfraOverrides.arn }}
domainId: {{ .Values.global.awsAccountNumber }}/{{ .Values.existingInfraOverrides.clusterDomainName }}
endpoint: {{ .Values.existingInfraOverrides.clusterEndpoint }}
protocol: {{ .Values.existingInfraOverrides.protocol }}
port: {{ .Values.existingInfraOverrides.port | quote }}
{{- end }}

{{/*
  Defines extra environment variables for the container
*/}}
{{- define "elasticsearch.localDeploymentExtraEnvVars" -}}
{{- if .Values.localDeployment.extraEnvVars }}
{{- toYaml .Values.localDeployment.extraEnvVars }}
{{- end }}
{{- end }}

{{/*
  Defines the endpoint configmap additional params for existing infrastructure for multienv_json
*/}}
{{- define "elasticsearch.multienvEndpointCMParams" -}}
{{- if .Values.multiEnvElasticSearch }}
{{- range $k, $v := .Values.multiEnvElasticSearch -}}
{{- if not ( and $v.clusterDomainName $v.clusterEndpoint ) -}}
{{ printf ("\n\nIf you have set \".Values.multiEnvElasticSearch\" as true then please provide a value for both: \"clusterDomainName\" and \"clusterEndpoint for the individual ElasticSearch instances\"") | fail }}
{{- end -}}
{{- end -}}
multi_elasticsearch_json: |
  {{ toJson .Values.multiEnvElasticSearch }}
{{- end -}}
{{- end -}}

{{/*
  Defines the endpoint configmap endpoint parameters, with validation
*/}}
{{- define "elasticsearch.endpoints" -}}
endpoint: {{ required "You must specify the value for existing Elasticsearch cluster Endpoint '.Values.existingInfraOverrides.clusterEndpoint' to be created."  .Values.existingInfraOverrides.clusterEndpoint }}
{{- if .Values.existingInfraOverrides.endpointUrls }}
endpointUrlsJson: |
  {{ .Values.existingInfraOverrides.endpointUrls | toJson }}
{{- end -}}
{{- end -}}